#include <librnd/hid/hid.h>

void rnd_gtk_glue_hid_init(rnd_hid_t *dst);
int rnd_gtk_parse_arguments(rnd_hid_t *hid, int *argc, char ***argv);

